@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a number into addition sequences
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use strict;
 use warnings;
@@ -41,7 +41,7 @@ sub choose {
         $label++;
     }
 
-    return @distribution;
+    return \@distribution;
 }
 
 1;
@@ -58,7 +58,7 @@ Math::Partition::Rand - Partition a number into addition sequences
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -91,7 +91,7 @@ Arguments and defaults:
 
 =head2 choose()
 
-  @vector = $self->choose;
+  $distribution = $partition->choose;
   # [ 0.3161932258724, 0.683806774127597 ] for instance
 
 Partition the given number B<top> into addition B<n> sequences.
